==> openshift-model-whereabouts-5.12.1-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/IPPoolBuilder.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IPPoolBuilder extends io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolFluentImpl<io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPool,io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolBuilder>{
  public IPPoolBuilder() {
    this(false);
  }
  public IPPoolBuilder(java.lang.Boolean validationEnabled) {
    this(new IPPool(), validationEnabled);
  }
  public IPPoolBuilder(io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolFluent<?> fluent) {
    this(fluent, false);
  }
  public IPPoolBuilder(io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IPPool(), validationEnabled);
  }
  public IPPoolBuilder(io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolFluent<?> fluent,io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPool instance) {
    this(fluent, instance, false);
  }
  public IPPoolBuilder(io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolFluent<?> fluent,io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPool instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public IPPoolBuilder(io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPool instance) {
    this(instance,false);
  }
  public IPPoolBuilder(io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPool instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPool build() {
    IPPool buildable = new IPPool(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IPPoolBuilder that = (IPPoolBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-whereabouts-6.0.0-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/IPPoolBuilder.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IPPoolBuilder extends IPPoolFluentImpl<IPPoolBuilder> implements VisitableBuilder<IPPool,IPPoolBuilder>{
  public IPPoolBuilder() {
    this(false);
  }
  public IPPoolBuilder(Boolean validationEnabled) {
    this(new IPPool(), validationEnabled);
  }
  public IPPoolBuilder(IPPoolFluent<?> fluent) {
    this(fluent, false);
  }
  public IPPoolBuilder(IPPoolFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IPPool(), validationEnabled);
  }
  public IPPoolBuilder(IPPoolFluent<?> fluent,IPPool instance) {
    this(fluent, instance, false);
  }
  public IPPoolBuilder(IPPoolFluent<?> fluent,IPPool instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public IPPoolBuilder(IPPool instance) {
    this(instance,false);
  }
  public IPPoolBuilder(IPPool instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  IPPoolFluent<?> fluent;
  Boolean validationEnabled;
  public IPPool build() {
    IPPool buildable = new IPPool(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
